/*
	String-Class - A class that could be used to simplify the handling of strings
	Copyright (C) 2003, 2004  Michael "Serpedon" Walz

	This file is part of the String-Class-Library

	String-Class-Library is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	String-Class-Library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with SerpEncrypTool; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/***************************************************************************/
/*											String Klasse										*/
/*					Copyright (C) 2003, 2004,  Michael "Serpedon" Walz				*/
/*									 Letzte nderung: 12.10.04								*/
/***************************************************************************/

/***************************************************************************/
/*										unter Mitarbeit von									*/
/*									Christopher "Esleborn" Nerz							*/
/*									 Letzte nderung: 06.01.04								*/
/***************************************************************************/

/***************************************************************************/
/* Beschreibung:																				*/
/*		String Klasse, die die Verwendung von Strings ( Zeichenketten )		*/
/*		vereinfacht.																			*/
/*		Einschrnkungen:																		*/
/*			- sehr beschrnkt UNICODE-fhig												*/
/*			- max. 2147483646 Zeichen ( 2 ^ 31 - 2 )									*/
/***************************************************************************/

# ifndef __KLASSE_STRING_HPP_INCLUDED__	// Vermeidung der Mehrfacheinbindung
# define __KLASSE_STRING_HPP_INCLUDED__

// Linken der Lib
# pragma comment ( lib, "Klasse.String.lib" )

// Typendefinitionen
typedef unsigned int uint;
typedef unsigned char uchar;
typedef unsigned short int ushort;
typedef unsigned long ulong;

// Konstanten
# define CASE_SENSITIVE		0
# define CASE_INSENSITIVE	1
# define NOTE_UMLAUTS		0
# define IGNORE_UMLAUTS		2
# define MAX_LONG				2147483647
# define LESS_MEMORY			-2
# define READ_EOF				-1
# define READ_SUCCESS		1

# include <stdarg.h>
# include <stdio.h>
# include <windows.h>

class UnicodeString;

class String
{
public:
	// Standartkonstruktor: Erstellt einen leeren String (""),
	// der nur die abschlieende '\0' erhlt.
	// Parameter: keine
	// Rckgabewerte: keine
	String ( );

	// Erstellt einen String mit den ersten f_count Buchstaben von fa_cString
	// Parameter: const char * const fa_cString, long f_count = MAX_LONG
	// fa_cString: ein char-Array
	// f_count: Die Anzahl der Buchstaben, die kopiert werden sollen
	//    (Oder bis zur ersten '\0'-Zeichen)
	// Rckgabewerte: keine
	String ( const char * const fa_cString, long f_count = MAX_LONG );	

	// Erstellt einen String mit den ersten f_count Buchstaben von fa_cString
	// Parameter: const WCHAR * const fa_cString, long f_count = MAX_LONG
	// fa_cString: ein WCHAR-Array
	// f_count: Die Anzahl der Buchstaben, die kopiert werden sollen
	//    (Oder bis zur ersten '\0'-Zeichen)
	// Rckgabewerte: keine
	String ( const WCHAR * const fa_cString, long f_count = MAX_LONG );	

		// Erstellt einen String, indem f_number in einen String umgewandelt wird
	// Parameter: const long f_number
	// f_number: die Zahl, die umgewandelt werden soll.
	// Rckgabewerte: keine
	String ( const long f_number );

	// Kopierkonstruktor
	// Parameter: const String & f_string
	// f_string: String der kopiert werden soll
	// Rckgabewerte: keine
	String ( const String & f_string );

	// Dekonstruktor
	// Parameter: keine
	// Rckgabewerte: keine
	~String ( );

	// Fgt this->ma_string und f_string->ma_string zusammen und gibt das Ergebnis zurck
	// Parameter: const String & f_string
	// f_string: Der String der angehngt wird.
	// Rckgabewerte: Ein neuer String der aus *this + f_string besteht
//	String operator+ ( const String & f_string ) const;

	// Fgt this->ma_string und fa_cString zusammen und gibt das Ergebnis zurck
	// Parameter: const char * fa_cString
	// fa_cString: das char-Array, das angehngt wird.
	// Rckgabewerte: Ein neuer String der aus *this + fa_cString besteht
	String operator+ ( const char * fa_cString ) const;

	// Chris behauptet, dass das hilft, wenn man ein char * + String machen will
	// Ergngzung: Chris hat recht: Man kann damit char * + String machen
	friend String operator+ ( const String & f_string1, const String & f_string2 );

	// Setzt den String auf f_string
	// Parameter: const String & f_string
	// s: Der String der zugewiesen wird
	// Rckgabewerte: *this
	String & operator= ( const String & f_string );

	// Setzt den String auf fa_cString
	// Parameter: const char * fa_cString
	// fa_cString: das char-Array, das zugewiesen wird
	// Rckgabewerte: *this
	String & operator= ( const char * fa_cString );

	// Setzt den String auf fa_cString
	// Parameter: const WCHAR * fa_cString
	// fa_cString: das WCHAR-Array, das zugewiesen wird
	// Rckgabewerte: *this
	String & operator= ( const WCHAR * fa_cString );

	// Hngt dem String f_string an
	// Parameter: const String & f_string
	// f_string: der String, der angehngt wird
	// Rckgabewerte: *this
	String & operator+= ( const String & f_string );

	// Hngt dem String das char-Array fa_cString an
	// Parameter: const char * fa_cString
	// fa_cString: das char-Array, das angehngt wird
	// Rckgabewerte: *this
	String & operator+= ( const char * fa_cString );

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei !=
	bool operator!= ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei !=
	bool operator!= ( const char * fa_cString ) const;

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei ==
	bool operator== ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei ==
	bool operator== ( const char * fa_cString ) const;

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei <
	bool operator< ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei <
	bool operator<  ( const char * fa_cString ) const;

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei <=
	bool operator<= ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei <=
	bool operator<= ( const char * fa_cString ) const;

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei >
	bool operator> ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei >
	bool operator> ( const char * fa_cString ) const;

	// Vergleicht this->ma_string mit f_string->ma_string
	// Parameter: const String & f_string
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// f_string: der String mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei >=
	bool operator>= ( const String & f_string ) const;

	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString
	// Vergleichsmethode: CASE_INSENITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// Rckgabewerte: true, bei >=
	bool operator>= ( const char * fa_cString ) const;

	// Gibt einen nicht-konstanten Zeiger auf this->ma_string zurck
	// Dadurch wird: string[ 10 ] = '\a'; mglich
	operator char * ( );

	// Gibt einen konstanten Zeiger auf this->ma_string zurck
	operator const char * ( ) const;
	
	// Vergleicht this->ma_string mit fa_cString
	// Parameter: const char * fa_cString, uchar f_type = CASE_INSENSITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// f_type:	CASE_SENSITIVE oder CASE_INSENSITIVE
	//					NOTE_UMLAUTS   oder IGNORE_UMLAUTS
	// Rckgabewerte: <0 wenn *this < fa_cString
	//                =0 wenn *this = fa_cString
	//                >0 wenn *this > fa_cString
	char Compare ( const char * fa_cString, const uchar f_type = CASE_INSENSITIVE | NOTE_UMLAUTS ) const;

	// Sucht fa_cString im String
	// Parameter: const char * fa_cString, const f_start = 0,
	//				  const uchar f_type = CASE_INSENSITIVE | NOTE_UMLAUTS
	// fa_cString: das char-Array, mit dem *this verglichen werden soll
	// f_start: Bezeichnet die Stelle im String, bei der angefangen wird zu suchen
	// f_type:	CASE_SENSITIVE oder CASE_INSENSITIVE
	//				NOTE_UMLAUTS   oder IGNORE_UMLAUTS
	// Rckgabewerte: Stelle des 1. Vorkommens zurck; -1 bei nicht-Erfolg
	long Find ( const char * fa_cString, long f_start = 0,
			/* <-- */ const uchar f_type = CASE_INSENSITIVE | NOTE_UMLAUTS ) const;		
			
	// Wandelt die Zahl f_number in einen String um und hngt diesen an
	// Parameter: const long f_number
	// f_number: Die Zahl, die umgewandelt und angehngt wird
	// Rckgabewerte: *this
	String & AddNumber ( const long f_number );

	// Lscht den Inhalt des Strings (Neuer Wert: "")
	// Parameter: keine
	// Rckgabewerte: *this
	String & Clear ( );

	// Formatierung wie printf unter Benutzung des String als Ausgabemedium
	// Parameter: const char * fa_format, ...
	// fa_format: der Formatierungsstring
	// ...: Argumente, die wegen des Formatierungsstring gebraucht werden
	// Rckgabewerte: *this
	String & Format ( const char * fa_format, ... );

	// Formatierung wie printf unter Benutzung des String als Ausgabemedium
	// Parameter: const char * fa_format, va_list & f_argumente
	// fa_format: der Formatierungsstring
	// f_argumente: Argumente, die wegen des Formatierungsstring gebraucht werden
	// Rckgabewerte: *this
	String & FormatV ( const char * fa_format, va_list & f_arguments );

	// Wandelt den String in Kleinbuchstaben um
	// Parameter: const uchar f_type = NOTE_UMLAUTS
	// f_type: NOTE_UMLAUTS oder IGNORE_UMLAUTS
	// Rckgabewerte: *this
	String & MakeLower ( const uchar f_type = NOTE_UMLAUTS );

	// Dreht den String um (Reverse->esreveR)
	// Parameter: keine
	// Rckgabewerte: *this
	String & MakeReverse ( );

	// Wandelt den String in Grobuchstaben um
	// Parameter: const uchar f_type = NOTE_UMLAUTS
	// f_type: NOTE_UMLAUTS oder IGNORE_UMLAUTS
	// Rckgabewerte: *this
	String & MakeUpper ( const uchar f_type = NOTE_UMLAUTS );

	// Wandelt Sonderzeichen in normale Zeichen um.
	// (->A, ->e, ->i, etc.)
	// Parameter: keine
	// Rckgabewerte: *this
	String & DeleteUmlauts ( );

	// Liest eine Zeile aus einer Datei aus
	// Parameter: FILE * f_file, char f_lineEnd = '\n'
	// f_file: Die Datei aus der gelesen wird
	// f_lineEnd: Der char, der das Zeilenende markiert.
	// Rckgabewerte: 
	//   LESS_MEMORY
	//   READ_EOF
	//   READ_SUCCESS
	char ReadLine ( FILE * f_file, char f_lineEnd = '\n' );

	// Schreibt eine Zeile in einer Datei aus
	// Parameter: FILE * f_file, char f_lineEnd = '\n'
	// f_file: Die Datei in die geschrieben wird
	// f_lineEnd: Der char, der das Zeilenende markiert.
	void WriteLine ( FILE * f_file, char f_lineEnd = '\n' ) const;

	// Entfernt bestimmte Zeichen am Anfang des Strings
	// Parameter: const char * fa_chars = "\n\r \t"
	// fa_chars: ein String, der die Zeilen enthlt, die entfernt werden 
	// Rckgabewerte: *this
	String & LTrim ( const char * fa_chars = "\n\r \t" );
	
	// Entfernt bestimmte Zeichen am Ende des Strings
	// Parameter: const char * fa_chars = "\n\r \t"
	// fa_chars: ein String, der die Zeilen enthlt, die entfernt werden 
	// Rckgabewerte: *this
	String & RTrim ( const char * fa_chars = "\n\r \t" );

	// Entfernt bestimmte Zeichen an beiden Enden des Strings
	// Parameter: const char * fa_chars = "\n\r \t"
	// fa_chars: ein String, der die Zeilen enthlt, die entfernt werden 
	// Rckgabewerte: *this
	String & Trim ( const char * fa_chars = "\n\r \t" );

	// Verschlsselt einen String, indem BitOr angewendet wird
	// Parameter: const char * fa_bitOr
	// fa_bitOr: Der String, mit dem verschlsselt wird ( Wird so oft wiederhohlt, wie ntig )
	// Anmerkung: Wenn zu verschlsselnde String und den Verschlsselungsstring an einen Stelle
	//				  gleich sind, erfolgt keine XOR, weil sonst '\0' das Ergebnis wre
	// Rckgabewerte: *this
	String & Secure ( const char * fa_bitOr );

	// Ersetzt die Escape-Zeichenfolgen
	// z.B.: "\\n" durch "\n"
	// Parameter: keine
	// Rckgabewerte: *this
	String & ReplaceEscChars ( );

	// Verschlsselt einen String, indem BitOr angewendet wird
	// Parameter: const char * fa_bitOr
	// fa_bitOr: Der String, mit dem verschlsselt wird ( Wird so oft wiederhohlt, wie ntig )
	// Anmerkung: Wenn zu verschlsselnde String und den Verschlsselungsstring an einen Stelle
	//				  gleich sind, erfolgt keine XOR, weil sonst '\0' das Ergebnis wre
	// Rckgabewerte: ein neuer String der aus dem alten String ^ fa_bitOr besteht.
	String GetSecured ( const char * fa_bitOr ) const;

	// Liest eine Wert aus einer .ini-Datei aus
	// Parameter: const char * fa_section, const char * fa_key,
	//				  const char * fa_iniFile, const char * fa_default = ""
	// fa_section: [section]
	// fa_key: key=wert
	// fa_iniFile: Dateiname der .ini-Datei
	// fa_default: Rckgabestring, wenn Eintrag nicht vorhanden
	// Rckgabewerte: *this
	String & GetIniString ( const char * fa_section, const char * fa_key,
			/* <-- */			const char * fa_iniFile, const char * fa_default = "" );

	// Schreibt den String in eine .ini-Datei
	// Parameter: const char * fa_section, const char * fa_key,
	//				  const char * fa_iniFile
	// fa_section: [section]
	// fa_key: key=wert
	// fa_iniFile: Dateiname der .ini-Datei
	// Rckgabewerte: true, wenn erfolgreich
	bool WriteIniString ( const char * fa_section, const char * fa_key,
			/* <-- */		 const char * fa_iniFile ) const;

	// Gibt nCount Zeichen zurck und beginnt bei nFirst
	// Parameter: const long f_start, long f_count = MAX_LONG ) const;
	// f_start: Startadresse
	// f_count: Anzahl der Zeichen
	// Rckgabewerte: ein String, der ein Teilstring von *this ist
	String Mid ( long f_start, long f_count = MAX_LONG ) const;

	// Gibt die Lnge des Strings zurck
	// Parameter: keine
	// Rckgabewerte: Lnge des Strings
	long Length ( ) const;

	// Ersetzt jedes Vorkommen von f_oldChar durch f_newChar
	// Parameter: const char f_oldChar, const char f_newChar
	// f_oldChar: das Zeichen, das durch chNew ersetzt wird
	// f_newChar: das Zeichen, mit dem chOld ersetzt wird
	// Rckgabewerte: Anzahl der Ersetzungen
	long Replace ( const char f_oldChar, const char f_newChar );

	// Ersetzt jedes Vorkommen von fa_oldString durch fa_newString
	// Parameter:	const char * fa_oldString, const char * fa_newString,
	//					const uchar f_type = CASE_SENSITIVE | NOTE_UMLAUTS
	// fa_oldString: der String, der durch szNew ersetzt wird
	// fa_newString: der String, mit dem szOld ersetzt wird
	// f_type:	CASE_SENSITIVE oder CASE_INSENSITIVE
	//				NOTE_UMLAUTS   oder IGNORE_UMLAUTS
	// Rckgabewerte: Anzahl der Ersetzungen
	long Replace ( const char * fa_oldString, const char * fa_newString,
			/* <-- */  const uchar f_type = CASE_SENSITIVE | NOTE_UMLAUTS );
	
	// Wandelt den String in Unicode um
	// Parameter: WCHAR * * fpa_unicode
	// fpa_unicode: ein Zeiger auf eine WCHAR-Array, bekommt den reservierten Speicher
	//					 zugewiesen ( Dieser muss mit delete [] gelscht werden )
	// Rckgabewerte: ( * fpa_unicode )
	// Bsp: String test1 = "test";
	//		  WCHAR * test2;
	//		  test1.MakeUnicode ( & test2 );
	//      // Benutzen von test2
	//		  delete [ ] test2;
	WCHAR * MakeUnicode ( WCHAR * * fpa_unicode ) const;

private:
	// PRIVATER Konstruktor
	String ( const long * fp_newLength );

	// Zeiger auf den ersten Buchstaben des char-Arrays
	char * ma_string;
};

// Liest eine Zahl aus einer .ini-Datei aus
// Parameter: const char * fa_section, const char * fa_key,
//				  const char * fa_iniFile, const int f_default = -1
// fa_section: [section]
// fa_key: key=wert
// fa_iniFile: Dateiname der .ini-Datei
// f_default: Rckgabewert, wenn Eintrag nicht vorhanden
// Rckgabewerte: Die gelesene Zahl
int GetIniInt ( const char * fa_section, const char * fa_key,
		/* <-- */ const char * fa_iniFile, const int f_default = -1 );

// Schreibt eine Zahl in eine .ini-Datei
// Parameter: const char * fa_section, const char * fa_key,
//				  const char * fa_iniFile, const uint f_number );
// fa_section: [section]
// fa_key: key=wert
// fa_iniFile: Dateiname der .ini-Datei
// f_number: die Zahl, die geschrieben werden soll
// Rckgabewerte: true, wenn erfolgreich
bool WriteIniInt ( const char * fa_section, const char * fa_key,
		/* <-- */	 const char * fa_iniFile, const int f_number );

// Liest eine Wert aus einer .ini-Datei aus
// Parameter: const char * fa_section, const char * fa_key,
//				  const char * fa_iniFile, const char * fa_default = "" );
// fa_section: [section]
// fa_key: key=wert
// fa_iniFile: Dateiname der .ini-Datei
// fa_default: Rckgabestring, wenn Eintrag nicht vorhanden
// Rckgabewerte: String
String GetIniString ( const char * fa_section, const char * fa_key,
		/* <-- */		 const char * fa_iniFile, const char * fa_default = "" );

// Schreibt den String in eine .ini-Datei
// Parameter: const char * fa_section, const char * fa_key,
//				  const char * fa_iniFile, const char * fa_writeString = ""
// fa_section: [section]
// fa_key: key=wert
// fa_iniFile: Dateiname der .ini-Datei
// fa_writeString: String, der geschrieben werden soll
// Rckgabewerte: true, wenn erfolgreich
bool WriteIniString ( const char * fa_section, const char * fa_key,
		/* <-- */		 const char * fa_iniFile, const char * fa_writeString = "" );

// Ersetzt die Escape-Zeichenfolgen
// z.B.: "\\n" durch "\n"
void ReplaceEscChars ( char * fa_string );

// gibt true zurck, wenn der search-String auf den data-String zutrifft
// Folgende Wildcards existieren:
// ?: ein beliebiges Zeichen
// *: kein, ein, oder mehrere beliebige Zeichen
// %: ein oder kein beliebiges Zeichen
// Anmerkung: f_search wird evtl. optimiert
bool MatchesSearchStr ( char * fa_search, const char * fa_data );

// wenn erfolgreich, gibt die Anzahl der Tokens zurck, sonst -1
// Parameter: const char * fa_string, const char * fa_delims, String * fa_tokens
// fa_string: der String, der in Tokens geteilt wird
// fa_delims: Array von Trennzeichen (Bsp: ";, \t" )
// fa_tokens: Array von Strings, die die ausgelesenen Tokens empfangen;
//				  muss mindesten f_amount Elemente besitzen
// f_amount: Maximale Anzahl an Tokens
// ACHTUNG: Funktion benutzt 'strtok'
int Tokenize ( String f_string, const char * fa_delims, String * fa_tokens, int f_amount );

class UnicodeString
{
public:
	// Standartkonstruktor: Erstellt einen leeren String (""),
	// der nur die abschlieende '\0' erhlt.
	// Parameter: keine
	// Rckgabewerte: keine
	UnicodeString ( );

	// Erstellt einen String mit den ersten f_count Buchstaben von fa_cString
	// Parameter: const char * const fa_cString, long f_count = MAX_LONG
	// fa_wString: ein char-Array
	// f_count: Die Anzahl der Buchstaben, die kopiert werden sollen
	//    (Oder bis zur ersten '\0'-Zeichen)
	// Rckgabewerte: keine
	UnicodeString ( const char * const fa_wString, long f_count = MAX_LONG );	

	// Erstellt einen UnicodeString aus f_string
	// Parameter: const String & f_string
	// f_string: ein String
	// Rckgabewerte: keine
	UnicodeString ( const String & f_string );	
	
	// Kopierkonstruktor
	// Parameter: const UnicodeString & f_unicodeString
	// f_unicodeString: String der kopiert werden soll
	// Rckgabewerte: keine
	UnicodeString ( const UnicodeString & f_unicodeString );

	// Dekonstruktor
	// Parameter: keine
	// Rckgabewerte: keine
	~UnicodeString ( );

	// Setzt den String auf fa_cString
	// Parameter: const WCHAR * fa_cString
	// fa_cString: das WCHAR-Array, das zugewiesen wird
	// Rckgabewerte: *this
	UnicodeString & operator= ( const WCHAR * fa_cString );

	// Setzt den String auf f_unicodeString
	// Parameter: const UnicodeString & f_unicodeString
	// s: Der String der zugewiesen wird
	// Rckgabewerte: *this
	UnicodeString & operator= ( const UnicodeString & f_unicodeString );

	// Gibt einen nicht-konstanten Zeiger auf this->ma_string zurck
	operator WCHAR * ( );

	// Gibt einen konstanten Zeiger auf this->ma_string zurck
	operator const WCHAR * ( ) const;

private:
	// Zeiger auf den ersten Buchstaben des WCHAR-Arrays
	WCHAR * ma_string;
};

# endif // ifndef __KLASSE_STRING_HPP_INCLUDED__
